@@ -1,10 +1,10 @@
-# Copyrights 1995-2012 by [Mark Overmeer <perl@overmeer.net>].
+# Copyrights 1995-2016 by [Mark Overmeer <perl@overmeer.net>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.02.
 package Mail::Address;
 use vars '$VERSION';
-$VERSION = '2.11';
+$VERSION = '2.15';
 
 use strict;
 
@@ -131,6 +131,7 @@ sub _complete
     $o;
 }
 
+#------------
 
 sub new(@)
 {   my $class = shift;
@@ -158,14 +159,14 @@ sub parse(@)
         elsif($_ eq '<')    { $depth++ }
         elsif($_ eq '>')    { $depth-- if $depth }
         elsif($_ eq ',' || $_ eq ';')
-        {   warn "Unmatched '<>' in $line" if($depth);
+        {   warn "Unmatched '<>' in $line" if $depth;
             my $o = $class->_complete(\@phrase, \@address, \@comment);
             push @objs, $o if defined $o;
             $depth = 0;
             $next = _find_next $idx+1, $tokens, $len;
         }
         elsif($depth)       { push @address, $_ }
-        elsif($next eq "<") { push @phrase,  $_ }
+        elsif($next eq '<') { push @phrase,  $_ }
         elsif( /^[.\@:;]$/ || !@address || $address[-1] =~ /^[.\@:;]$/ )
         {   push @address, $_ }
         else
@@ -179,6 +180,7 @@ sub parse(@)
     @objs;
 }
 
+#------------
 
 sub phrase  { shift->set_or_get(0, @_) }
 sub address { shift->set_or_get(1, @_) }
@@ -230,6 +232,7 @@ sub format
     join ", ", @addrs;
 }
 
+#------------
 
 sub name
 {   my $self   = shift;
@@ -266,7 +269,7 @@ sub host
 
 sub user
 {   my $addr = shift->address || '';
-    my $i    = index $addr, '@';
+    my $i    = rindex $addr, '@';
     $i >= 0 ? substr($addr,0,$i) : $addr;
 }
 
