@@ -1,10 +1,10 @@
-# Copyrights 1995-2012 by [Mark Overmeer <perl@overmeer.net>].
+# Copyrights 1995-2016 by [Mark Overmeer <perl@overmeer.net>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.02.
 package Mail::Cap;
 use vars '$VERSION';
-$VERSION = '2.12';
+$VERSION = '2.15';
 
 use strict;
 
@@ -71,23 +71,28 @@ sub _process_file
     while(<MAILCAP>)
     {   next if /^\s*#/; # comment
         next if /^\s*$/; # blank line
-        $_ .= <MAILCAP> while s/\\\s*$//; # continuation line
+        $_ .= <MAILCAP>  # continuation line
+           while s/(^|[^\\])((?:\\\\)*)\\\s*$/$1$2/;
         chomp;
-        s/\0//g;            # ensure no NULs in the line
-        s/([^\\]);/$1\0/g;  # make field separator NUL
+        s/\0//g;              # ensure no NULs in the line
+        s/(^|[^\\]);/$1\0/g;  # make field separator NUL
+        my ($type, $view, @parts) = split /\s*\0\s*/;
 
-        my @parts = split /\s*\0\s*/, $_;
-        my $type  = shift @parts;
         $type    .= "/*" if $type !~ m[/];
-
-        my $view  = shift @parts;
         $view     =~ s/\\;/;/g;
+        $view     =~ s/\\\\/\\/g;
         my %field = (view => $view);
 
         foreach (@parts)
         {   my($key, $val) = split /\s*\=\s*/, $_, 2;
-            $val =~ s/\\;/;/g if defined $val;
-            $field{$key} = defined $val ? $val : 1;
+            if(defined $val)
+            {   $val =~ s/\\;/;/g;
+                $val =~ s/\\\\/\\/g;
+                $field{$key} = $val;
+            }
+            else
+            {   $field{$key} = 1;
+            }
         }
 
         if(my $test = $field{test})
