@@ -1,10 +1,10 @@
-# Copyrights 1995-2012 by [Mark Overmeer <perl@overmeer.net>].
+# Copyrights 1995-2016 by [Mark Overmeer <perl@overmeer.net>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.02.
 package Mail::Field;
 use vars '$VERSION';
-$VERSION = '2.11';
+$VERSION = '2.15';
 
 
 use Carp;
@@ -29,7 +29,7 @@ sub _header_pkg_name
 }
 
 sub _require_dir
-{   my($class,$dir,$dir_sep) = @_;
+{   my($class, $dir, $dir_sep) = @_;
 
     local *DIR;
     opendir DIR, $dir
@@ -47,6 +47,9 @@ sub _require_dir
         else
         {   $p =~ s/-/_/go;
             eval "require ${class}::$p";
+
+            # added next warning in 2.14, may be ignored for ancient code
+            warn $@ if $@;
         }
     }
     closedir DIR;
@@ -62,11 +65,12 @@ sub import
         return;
     }
 
-    my($dir,$dir_sep);
-    foreach my $f (keys %INC)
+    my ($dir, $dir_sep);
+    foreach my $f (grep defined $INC{$_}, keys %INC)
     {   next if $f !~ /^Mail(\W)Field\W/i;
         $dir_sep = $1;
-        $dir = ($INC{$f} =~ /(.*Mail\W+Field)/i)[0] . $dir_sep;
+# $dir = ($INC{$f} =~ /(.*Mail\W+Field)/i)[0] . $dir_sep;
+        ($dir = $INC{$f}) =~ s/(Mail\W+Field).*/$1$dir_sep/;
         last;
     }
 
