@@ -1,10 +1,10 @@
-# Copyrights 1995-2012 by [Mark Overmeer <perl@overmeer.net>].
+# Copyrights 1995-2016 by [Mark Overmeer <perl@overmeer.net>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.02.
 package Mail::Header;
 use vars '$VERSION';
-$VERSION = '2.11';
+$VERSION = '2.15';
 
 
 use strict;
@@ -117,11 +117,11 @@ sub _fold_line
     $_[0] =~ s/\A(\S+)\n\s*(?=\S)/$1 /so; 
 }
 
-# Tags are case-insensitive, but there is a (slightly) prefered construction
+# Tags are case-insensitive, but there is a (slightly) preferred construction
 # being all characters are lowercase except the first of each word. Also
 # if the word is an `acronym' then all characters are uppercase. We decide
 # a word is an acronym if it does not contain a vowel.
-# In general, this change of capitization is a bad idea, but it is in
+# In general, this change of capitalization is a bad idea, but it is in
 # the code for ages, and therefore probably crucial for existing
 # applications.
 
@@ -180,8 +180,15 @@ sub _fmt_line
               || $HDR_LENGTHS{$tag}
               || $self->fold_length;
 
-    _fold_line $line, $maxlen
-        if $modify && defined $maxlen;
+    if ($modify && defined $maxlen)
+    {   # folding will fix bad header continuations for us
+        _fold_line $line, $maxlen;
+    }
+    elsif($line =~ /\r?\n\S/)
+    {   return _error "Bad header continuation, skipping '$tag': ",
+                      "no space after newline in '$line'\n";
+    }
+
 
     $line =~ s/\n*$/\n/so;
     ($tag, $line);
@@ -275,21 +282,22 @@ sub extract
 {   my ($self, $lines) = @_;
     $self->empty;
 
-    while(@$lines && $lines->[0] =~ /^($FIELD_NAME|From )/o)
-    {    my $tag  = $1;
-         my $line = shift @$lines;
-         $line   .= shift @$lines
-             while @$lines && $lines->[0] =~ /^[ \t]+/o;
+    while(@$lines)
+    {   my $line = shift @$lines;
+        last if $line =~ /^\s*$/;
 
-         ($tag, $line) = _fmt_line $self, $tag, $line;
+        $line    =~ /^($FIELD_NAME|From )/o or next;
+        my $tag  = $1;
 
-         _insert $self, $tag, $line, -1
-             if defined $line;
+        $line   .= shift @$lines
+            while @$lines && $lines->[0] =~ /^[ \t]+/;
+
+        ($tag, $line) = _fmt_line $self, $tag, $line;
+
+        _insert $self, $tag, $line, -1
+            if defined $line;
     }
 
-    shift @$lines
-        if @$lines && $lines->[0] =~ /^\s*$/o;
-
     $self;
 }
 
@@ -299,13 +307,12 @@ sub read
 
     $self->empty;
 
-    my ($tag, $line);
-    my $ln = '';
+    my ($ln, $tag, $line);
     while(1)
     {   $ln = <$fd>;
 
-        if(defined $ln && defined $line && $ln =~ /\A[ \t]+/o)
-        {   $line .= $ln;
+        if(defined $ln && defined $line && $ln =~ /^[ \t]+/)
+        {   $line .= $ln;  # folded line
             next;
         }
 
@@ -313,11 +320,12 @@ sub read
         {   ($tag, $line) = _fmt_line $self, $tag, $line;
             _insert $self, $tag, $line, -1
 	        if defined $line;
+            ($tag, $line) = ();
         }
 
-        defined $ln && $ln =~ /^($FIELD_NAME|From )/o
-            or last;
+        last if $ln =~ m/^\s+$/;
 
+        $ln =~ /^($FIELD_NAME|From )/o or next;
         ($tag, $line) = ($1, $ln);
     }
 
