@@ -1,12 +1,12 @@
-# Copyrights 1995-2012 by [Mark Overmeer <perl@overmeer.net>].
+# Copyrights 1995-2016 by [Mark Overmeer <perl@overmeer.net>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.02.
 use strict;
 
 package Mail::Mailer;
 use vars '$VERSION';
-$VERSION = '2.10';
+$VERSION = '2.15';
 
 use base 'IO::Handle';
 
@@ -37,7 +37,7 @@ our %Mailers = @Mailers;
 our $MailerType;
 our $MailerBinary;
 
-# does this really need to be done? or should a default mailer be specfied?
+# does this really need to be done? or should a default mailer be specified?
 
 $Mailers{sendmail} = 'sendmail'
     if $^O eq 'os2' && ! is_exe $Mailers{sendmail};
@@ -155,8 +155,9 @@ sub open($)
         }
     }
     else
-    {   $self->exec($exe, $args, \@to, $sender)
-            or die $!;
+    {   # Sending is handled by a subclass
+        $self->exec(undef, $args, \@to)
+            or die $!;    
     }
 
     $self->set_headers($hdrs);
